OC.L10N.register(
    "calendar",
    {
    "Calendar" : "දිනදසුන",
    "Today" : "අද",
    "Week" : "සතිය",
    "Month" : "මාසය",
    "Download" : "බාන්න",
    "Delete" : "මකා දමන්න",
    "Share link" : "Share link",
    "can edit" : "සංස්කරණය කළ හැක",
    "New calendar" : "නව දින දර්ශනය",
    "Cancel" : "එපා",
    "Email" : "විද්‍යුත් තැපෑල",
    "Unknown" : "නොදනී",
    "never" : "කවදාවත්",
    "Repeat" : "පුනරාවර්ථන",
    "Monday" : "සඳුදා",
    "More" : "වැඩි",
    "Save" : "සුරකින්න",
    "Update" : "යාවත්කාල කිරීම",
    "Personal" : "පෞද්ගලික",
    "Attendees" : "කැටුව යන්නන්",
    "Close" : "වසන්න",
    "Daily" : "දිනපතා",
    "Weekly" : "සතිපතා",
    "today" : "අද",
    "Location" : "ස්ථානය",
    "Description" : "විස්තරය",
    "Mail" : "තැපෑල",
    "Play" : "ධාවනය"
},
"nplurals=2; plural=(n != 1);");
